Module cache_handlers

Module cache_handlers 

Shared cache and pub/sub HTTP request handlers.

These functions implement the cache command dispatch and pub/sub operations. They are used by both the main server (/api/cache, /api/pubsub/*) and the standalone cache server (/cache, /pubsub/*).

Functions

handle_cache_command
Handle a POST /cache (or POST /api/cache) request body.
handle_cache_delete
Handle a DELETE /cache/:key shorthand request.
handle_cache_get
Handle a GET /cache/:key shorthand request.
handle_pubsub_channels
Handle a GET /pubsub/channels request.
handle_pubsub_history
Handle a GET /pubsub/history/:channel request.
handle_pubsub_publish
Handle a POST /pubsub/publish request.