pub struct Logger { /* private fields */ }Expand description
A thread-safe structured logger that writes to stderr.
Thread safety is achieved without a Mutex — each call formats the full
line into a String first, then writes it in a single write_all call
to stderr. On Unix-like systems writes of reasonable size to stderr are
atomic at the fd level.
Implementations
Sourceimpl Logger
impl Logger
pub fn new(min_level: LogLevel) -> Self
Sourcepub fn enabled(&self, level: LogLevel) -> bool
pub fn enabled(&self, level: LogLevel) -> bool
Returns true if a message at level would be emitted.
Sourcepub fn log(
&self,
level: LogLevel,
target: &str,
message: &str,
fields: HashMap<String, String>,
)
pub fn log( &self, level: LogLevel, target: &str, message: &str, fields: HashMap<String, String>, )
Core logging method. Messages below min_level are silently dropped.
pub fn info(&self, target: &str, message: &str, fields: HashMap<String, String>)
pub fn warn(&self, target: &str, message: &str, fields: HashMap<String, String>)
pub fn error( &self, target: &str, message: &str, fields: HashMap<String, String>, )
pub fn debug( &self, target: &str, message: &str, fields: HashMap<String, String>, )
pub fn trace( &self, target: &str, message: &str, fields: HashMap<String, String>, )