Shared cache and pub/sub HTTP request handlers.
These functions implement the cache command dispatch and pub/sub operations.
They are used by both the main server (/api/cache, /api/pubsub/*) and
the standalone cache server (/cache, /pubsub/*).
Functions
- handle_
cache_ command - Handle a
POST /cache(orPOST /api/cache) request body. - handle_
cache_ delete - Handle a
DELETE /cache/:keyshorthand request. - handle_
cache_ get - Handle a
GET /cache/:keyshorthand request. - handle_
pubsub_ channels - Handle a
GET /pubsub/channelsrequest. - handle_
pubsub_ history - Handle a
GET /pubsub/history/:channelrequest. - handle_
pubsub_ publish - Handle a
POST /pubsub/publishrequest.