pub struct WorkflowEngine { /* private fields */ }Implementations
Sourceimpl WorkflowEngine
impl WorkflowEngine
pub fn new(runner_url: &str, max_history: usize) -> Self
Sourcepub fn register(&self, def: WorkflowDef)
pub fn register(&self, def: WorkflowDef)
Register a workflow definition.
Sourcepub fn start(&self, name: &str, input: Value) -> Result<String, String>
pub fn start(&self, name: &str, input: Value) -> Result<String, String>
Start a new workflow instance. Returns the instance ID.
Sourcepub fn advance(&self, workflow_id: &str) -> Result<WorkflowStatus, String>
pub fn advance(&self, workflow_id: &str) -> Result<WorkflowStatus, String>
Execute the next step of a workflow by calling the TS runner.
The TS runner returns an action object describing what happened:
{ "action": "step_complete", "step_name": "...", "output": ... }{ "action": "sleep", "duration": "24h" }{ "action": "wait_event", "event": "user_confirmed" }{ "action": "complete", "output": ... }{ "action": "fail", "error": "...", "step_name": "..." }
Sourcepub fn advance_with_response(
&self,
workflow_id: &str,
response: Value,
) -> Result<WorkflowStatus, String>
pub fn advance_with_response( &self, workflow_id: &str, response: Value, ) -> Result<WorkflowStatus, String>
Advance a workflow with a pre-provided response (for testing without a running TS runner).
Sourcepub fn send_event(
&self,
workflow_id: &str,
event: &str,
data: Value,
) -> Result<(), String>
pub fn send_event( &self, workflow_id: &str, event: &str, data: Value, ) -> Result<(), String>
Send an event to a waiting workflow.
Sourcepub fn get(&self, workflow_id: &str) -> Option<WorkflowInstance>
pub fn get(&self, workflow_id: &str) -> Option<WorkflowInstance>
Get a workflow instance by ID.
Sourcepub fn list(&self, status: Option<&WorkflowStatus>) -> Vec<WorkflowInstance>
pub fn list(&self, status: Option<&WorkflowStatus>) -> Vec<WorkflowInstance>
List all workflow instances with optional status filter.
Sourcepub fn definitions(&self) -> Vec<WorkflowDef>
pub fn definitions(&self) -> Vec<WorkflowDef>
List registered workflow definitions.
Sourcepub fn wake_sleeping(&self) -> Vec<String>
pub fn wake_sleeping(&self) -> Vec<String>
Wake sleeping workflows whose timer has expired. Returns the IDs of workflows that were woken.
Sourcepub fn restore_from(&self, store: &WorkflowStore) -> usize
pub fn restore_from(&self, store: &WorkflowStore) -> usize
Restore active and sleeping workflows from a persistent store.
Loads all non-terminal workflows and inserts them into the in-memory instance map. Returns the number of workflows restored.
Call this once at startup, before the engine begins processing.